.. role:: hidden
    :class: hidden-section

gpytorch.functions
===================================

.. currentmodule:: gpytorch.functions


Functions
----------------

.. automodule:: gpytorch

.. autofunction:: add_diagonal

.. autofunction:: add_jitter

.. autofunction:: dsmm

.. autofunction:: diagonalization

.. autofunction:: inv_quad

.. autofunction:: inv_quad_logdet

.. autofunction:: pivoted_cholesky

.. autofunction:: root_decomposition

.. autofunction:: root_inv_decomposition

.. autofunction:: solve

.. autofunction:: sqrt_inv_matmul
